# miniOSL

Python interface to [OSL (open shogi library)](https://gps.tanaka.ecc.u-tokyo.ac.jp/gpsshogi/index.php?GPSshogi) refurbished by C++20 and by pybind11.

WIP.

## demo@colab

https://colab.research.google.com/drive/1orT32kOR58owC0SfhPdC0yodFdn8h2nX?usp=share_link

## pip wheel

- https://pypi.org/project/miniosl/

## build from source

- C++20 (tested with g++ 12.2.1 in `manylinux_2_28`, Apple clang 14.0.3)
- Python 3.10+
- cmake 3.22+

